# What is this?

This is a plugin for [Lektor](https://github.com/lektor/lektor/) integrates the [SimpleMDE](https://github.com/sparksuite/simplemde-markdown-editor) visual markdown editor. It attaches SimpleMDE to all fields of type **markdown** according to the model

# Installation
Install the plugin from pypi with one of the [standard ways](https://www.getlektor.com/docs/plugins/). No settings are required.

# Known issues

Currently, the editor is also shown for **text** fields i.e. it is shown for all fields that render as a <textarea> in the admin interface.

# License
The plugin is distributed under the [MIT license](https://opensource.org/licenses/MIT)

# Support
If you have problems or suggestions, submit them via issues here or use [Spherical support form](https://www.spherical.pm/about/#contacts)

